@@ -1199,6 +1199,7 @@ QUERY_MODIFIERS = {
 class Table(Expression):
     arg_types = {
         "this": True,
+        "alias": False,
         "db": False,
         "catalog": False,
         "laterals": False,
@@ -3284,7 +3285,10 @@ def alias_(expression, alias, table=False, dialect=None, quoted=None, **opts):
     """
     exp = maybe_parse(expression, dialect=dialect, **opts)
     alias = to_identifier(alias, quoted=quoted)
-    alias = TableAlias(this=alias) if table else alias
+
+    if table:
+        expression.set("alias", TableAlias(this=alias))
+        return expression
 
     # We don't set the "alias" arg for Window expressions, because that would add an IDENTIFIER node in
     # the AST, representing a "named_window" [1] construct (eg. bigquery). What we want is an ALIAS node
@@ -3336,7 +3340,7 @@ def column(col, table=None, quoted=None):
     )
 
 
-def table_(table, db=None, catalog=None, quoted=None):
+def table_(table, db=None, catalog=None, quoted=None, alias=None):
     """Build a Table.
 
     Args:
@@ -3351,6 +3355,7 @@ def table_(table, db=None, catalog=None, quoted=None):
         this=to_identifier(table, quoted=quoted),
         db=to_identifier(db, quoted=quoted),
         catalog=to_identifier(catalog, quoted=quoted),
+        alias=TableAlias(this=to_identifier(alias)) if alias else None,
     )
 
 
@@ -3494,7 +3499,7 @@ def replace_tables(expression, mapping):
     Examples:
         >>> from sqlglot import exp, parse_one
         >>> replace_tables(parse_one("select * from a.b"), {"a.b": "c"}).sql()
-        'SELECT * FROM "c"'
+        'SELECT * FROM c'
 
     Returns:
         The mapped expression
@@ -3504,7 +3509,10 @@ def replace_tables(expression, mapping):
         if isinstance(node, Table):
             new_name = mapping.get(table_name(node))
             if new_name:
-                return table_(*reversed(new_name.split(".")), quoted=True)
+                return to_table(
+                    new_name,
+                    **{k: v for k, v in node.args.items() if k not in ("this", "db", "catalog")},
+                )
         return node
 
     return expression.transform(_replace_tables)
