@@ -329,6 +329,7 @@ class Parser:
         exp.DataType: lambda self: self._parse_types(),
         exp.From: lambda self: self._parse_from(),
         exp.Group: lambda self: self._parse_group(),
+        exp.Identifier: lambda self: self._parse_id_var(),
         exp.Lateral: lambda self: self._parse_lateral(),
         exp.Join: lambda self: self._parse_join(),
         exp.Order: lambda self: self._parse_order(),
@@ -497,7 +498,7 @@ class Parser:
         max_errors=3,
         null_ordering=None,
     ):
-        self.error_level = error_level or ErrorLevel.RAISE
+        self.error_level = error_level or ErrorLevel.IMMEDIATE
         self.error_message_context = error_message_context
         self.index_offset = index_offset
         self.unnest_column_only = unnest_column_only
@@ -1146,7 +1147,7 @@ class Parser:
 
     def _parse_annotation(self, expression):
         if self._match(TokenType.ANNOTATION):
-            return self.expression(exp.Annotation, this=self._prev.text, expression=expression)
+            return self.expression(exp.Annotation, this=self._prev.text.strip(), expression=expression)
 
         return expression
 
@@ -1275,7 +1276,7 @@ class Parser:
         alias = self._parse_table_alias()
 
         if alias:
-            this = self.expression(exp.Alias, this=this, alias=alias)
+            this.set("alias", alias)
 
         if not self.alias_post_tablesample:
             table_sample = self._parse_table_sample()
